pysqueezecenter.server.Server — PySqueezeCenter v0.1 documentation

### Navigation

- index
- next |
- previous |
- PySqueezeCenter v0.1 documentation »

# `pysqueezecenter.server.Server`

class `pysqueezecenter.server.` `Server`(hostname='localhost', port=9090, username='', password='')
  `connect`()
    Connect
  `get_player`(id=None)
    Get Player
  `get_player_count`()
    Get Number Of Players
  `get_players`()
    Get Players
  `get_version`()
    Get Version

### Navigation

- index
- next |
- previous |
- PySqueezeCenter v0.1 documentation »